# open-moldyn

Open Molecular Dynamics tools in Python 3

read the doc on https://open-moldyn.readthedocs.io/en/latest/

## Installation instructions

The package is on PyPI, to install use :
```
pip install open-moldyn
```

To update the package use :
```
pip install -U open-moldyn
```

To run open-moldyn's GUI use the script:
```
moldyn-gui
```

If it does not work in your terminal, 
maybe your python installation is not in the PATH.

